.. Pandora documentation master file, created by
   sphinx-quickstart on Fri Apr  3 16:11:03 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pandora's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   userguide
   api_reference/index.rst
   developer_guide

.. api_reference is automatically generated by sphinx-autoapi


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
